@@ -28,12 +28,18 @@ function(x,para,...) {
     else if(type == 'gum') {
       return(cdfgum(x,para))
     }
+    else if(type == 'kur') {
+      return(cdfkur(x,para))
+    }
     else if(type == 'ln3') {
       return(cdfln3(x,para))
     }
     else if(type == 'ray') {
       return(cdfray(x,para))
     }
+    else if(type == 'rice') {
+      return(cdfrice(x,para))
+    }
     else if(type == 'revgum') {
       return(cdfrevgum(x,para))
     }
