@@ -1,7 +1,6 @@
 "quawak" <-
 function(f,wakpara) {
-    #
-    #   UFL SHOULD BE CHOSEN SO THAT EXP(UFL) JUST DOES NOT CAUSE
+    #    #   UFL SHOULD BE CHOSEN SO THAT EXP(UFL) JUST DOES NOT CAUSE
     #    UNDERFLOW 
     #
     UFL <- log(.Machine$double.xmin);
@@ -9,20 +8,17 @@ function(f,wakpara) {
     if(! are.parwak.valid(wakpara)) return()
 
     XI <- wakpara$para[1]
-    A <- wakpara$para[2]
-    B <- wakpara$para[3]
-    C <- wakpara$para[4]
-    D <- wakpara$para[5]
+    A <- wakpara$para[2] # alpha
+    B <- wakpara$para[3] # beta
+    C <- wakpara$para[4] # gamma
+    D <- wakpara$para[5] # delta
     n <- length(f)
     x <- vector(mode="numeric",length=n)
     for(i in seq(1,n)) {
       if(f[i] == 0) { x[i] <- XI; next }
       if(f[i] == 1) {
-        if(D < 0) { x[i] <- XI+A/B-C/D; next }
-        if(D == 0 & C == 0 & B > 0) { x[i] <- XI+A/B; next }
-        if(D < 0 | B == 0) { x[i] <- Inf }
-        warning("argument of function is invalid")
-        return()
+        x[i] <- XI+A/B*(1-0^B) - C/D*(1 - 0^(-D))
+        next
       }
       Z <- -log(1-f[i])
       Y1 <- Z
@@ -43,3 +39,16 @@ function(f,wakpara) {
     return(x)
 }
 
+#   30 IF(D.GT.ZERO)GOTO 1010 
+#      IF(D.LT.ZERO)QUAWAK=XI+A/B-C/D 
+#      IF(D.EQ.ZERO.AND.C.GT.ZERO)GOTO 1010 
+#      IF(D.EQ.ZERO.AND.C.EQ.ZERO.AND.B.EQ.ZERO)GOTO 1010 
+#      IF(D.EQ.ZERO.AND.C.EQ.ZERO.AND.B.GT.ZERO)QUAWAK=XI+A/B 
+#      RETURN 
+#C 
+# 1000 WRITE(6,7000) 
+#      QUAWAK=ZERO 
+#      RETURN 
+# 1010 WRITE(6,7010) 
+#      QUAWAK=ZERO 
+#      RETURN 
